Crate sidedns_core

Crate sidedns_core 

Re-exports

pub use ipc::DnsEvent;
pub use ipc::IpcClient;
pub use ipc::IpcRequest;
pub use ipc::IpcResponse;
pub use logging::init as init_logging;
pub use store::RuleStore;

Modules

certs
ipc
logging
store

Macros

cert_key_path
cert_path

Structs

AppState
The daemon’s central state.
DnsRule
A single DNS routing rule mapping a domain to a target.

Constants

APP_DIR_NAME
APP_NAME
CERT_NAME
DAEMON_ENV
DNS_LISTEN_ADDR
DNS_RECORD_TTL_SECONDS
IPC_SOCKET_PATH
PROXY_LISTEN_ADDR

Statics

APP_DATA_DIR
DOMAIN_REGEX
ROOT_CERTIFICATE_DIR

Functions

platform_dns_manager
Return the best available [DnsConfigurator] for the current platform.
run
Run the daemon until a shutdown signal is received.
validate_domain

Type Aliases

SharedState