Skip to main contentModule ipc
Source - IpcClient
- Client for communicating with a running
super::IpcServer. - IpcServer
- Listens on a local socket and dispatches connections to an
IpcHandler.
- DnsEvent
- Events emitted by the daemon and pushed to subscribed clients.
- IpcError
- Errors specific to the IPC layer.
- IpcRequest
- Commands sent from CLI or GUI to the daemon over IPC.
- IpcResponse
- Responses sent from the daemon to a client.
- IpcHandler
- Implemented by the daemon’s shared state to handle incoming IPC requests.